Date: 08 7, 2001 3:42:25 PM

# Using the Attribute Editor

You can edit the attributes of a concept or node in the Knowledge Base using the Attribute Editor. The Attribute Editor is particularly handy when creating or working with a lexicon as you can edit lexical items directly.

To access the Attribute Editor:

- From the KB Menu, select Attribute Editor.

Note: You can also access the Attribute Editor from the following: In the KB Editor, Gram Tab, Ana Tab, and Text Tab, right-click on a concept and select Attributes. In an open text file, highlight a word and select Dictionary > KB Attributes from the menu. If the word exists in the dict hierarchy, the Attribute Editor will be launched.

See Attribute Editor Description for details on the Attribute Editor buttons.